pub struct NetlinkSocket { /* private fields */ }Available on crate feature
std or non-crate feature async only.Implementations
Sourceimpl NetlinkSocket
impl NetlinkSocket
Sourcepub fn request_chained<'a, Chained>(
&'a mut self,
request: &'a Chained,
) -> Result<NetlinkReplyChained<'a>>
pub fn request_chained<'a, Chained>( &'a mut self, request: &'a Chained, ) -> Result<NetlinkReplyChained<'a>>
Execute a chained request (experimental)
Some subsystems have special requirements for related requests, expecting certain types of messages to be sent within a single write operation. For example transactions in nftables subsystem.
Chained requests currently don’t support replies carrying data.
Sourceimpl NetlinkSocket
impl NetlinkSocket
pub fn new() -> Self
Sourcepub fn reserve_seq(&mut self, len: u32) -> u32
pub fn reserve_seq(&mut self, len: u32) -> u32
Reserve a sequential chunk of seq values, so chained messages don’t
get confused. A random seq number might be used just as well.
pub fn request<'sock, Request>(
&'sock mut self,
request: &Request,
) -> Result<NetlinkReply<'sock, Request>>where
Request: NetlinkRequest,